<?php

namespace Drupal\fox\Plugin\FoxCommand;

/**
 * BROWSE fox command.
 *
 * @FoxCommand(
 *   id = "browse",
 *   label = @Translation("Browse fields for context record. Usage: BROWSE {*|fields}")
 * )
 */
class FoxCommandBrowse extends FoxCommandBaseClass {

  /**
   * {@inheritdoc}
   */
  public function execute(array $params, array $variables): array {
    $helper = $this->foxCommandsHelper();

    $entity = $helper->getEntity($variables);
    if (is_array($entity) and isset($entity['error'])) {
      return $entity;
    }
    if (empty($entity)) {
      return [
        'error' => $this->t('Empty entity'),
      ];
    }

    $param = reset($params);
    if (empty($param)) {
      $param = $helper->entityKey($variables['entity_type'], 'id');
    }

    $fieldsList = $entity->getFields();

    // Creating field list.
    if ($param === '*') {
      $fields = array_keys($fieldsList);
    }
    else {
      $fields = explode(',', $param);
    }

    $data = $row = $header = [];
    foreach ($fields as $field) {
      $name = trim($field);
      if (!$entity->hasField($name)) {
        continue;
      }
      $value = $entity->get($name)->getString();
      $row[] = $value;

      $definition = $fieldsList[$name]->getFieldDefinition();
      $header[] = $definition->getLabel() . ' (' . $definition->getName() . ')';
    }
    $data[] = $row;

    return [
      'message' => [
        'header' => $header,
        'data' => $data,
      ],
    ];
  }

}
